from myterial import (
    indigo_light,
    orange,
    blue,
    blue_light,
    pink,
    green_dark,
    green,
    indigo_lighter,
    red,
    red_light,
    teal_light,
    teal_lighter,
)


"""
    Colors used to highlight string expressions
    for nice printing with Rich.
"""

equal = red
operator = red_light
operator_dark = blue_light
number = teal_light
parenthesis = blue
text = indigo_lighter
text_accent = indigo_light
solution = pink
result = pink
result_panel = green
result_panel_footer = green_dark
unicode = teal_lighter
variable = orange
